==> h2o-java-rest-bindings-3.8.2.6-sources.jar: water/bindings/pojos/ModelMetricsMultinomialV3.java <==
package water.bindings.pojos;

import com.google.gson.Gson;

public class ModelMetricsMultinomialV3 extends ModelMetricsBase {
    /** The R^2 for this scoring run. */
    public double r2;

    /** The hit ratio table for this scoring run. */
    public TwoDimTableV3 hit_ratio_table;

    /** The ConfusionMatrix object for this scoring run. */
    public ConfusionMatrixV3 cm;

    /** The logarithmic loss for this scoring run. */
    public double logloss;

    /* INHERITED: The model used for this scoring run. 
    public ModelKeyV3 model = null;
     */

    /* INHERITED: The checksum for the model used for this scoring run. 
    public long model_checksum = 0L;
     */

    /* INHERITED: The frame used for this scoring run. 
    public FrameKeyV3 frame = null;
     */

    /* INHERITED: The checksum for the frame used for this scoring run. 
    public long frame_checksum = 0L;
     */

    /* INHERITED: Optional description for this scoring run (to note out-of-bag, sampled data, etc.) 
    public String description = "";
     */

    /* INHERITED: The category (e.g., Clustering) for the model used for this scoring run. 
    public ModelCategory model_category = null;
     */

    /* INHERITED: The time in mS since the epoch for the start of this scoring run. 
    public long scoring_time = 0L;
     */

    /* INHERITED: Predictions Frame. 
    public FrameV3 predictions = null;
     */

    /* INHERITED: The Mean Squared Error of the prediction for this scoring run. 
    public double MSE = 0.0;
     */

    public ModelMetricsMultinomialV3() {
        r2 = 0.0;
        hit_ratio_table = null;
        cm = null;
        logloss = 0.0;
        model = null;
        model_checksum = 0L;
        frame = null;
        frame_checksum = 0L;
        description = "";
        model_category = null;
        scoring_time = 0L;
        predictions = null;
        MSE = 0.0;
    }

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}

==> h2o-java-rest-bindings-3.8.2.8-sources.jar: water/bindings/pojos/ModelMetricsMultinomialV3.java <==
package water.bindings.pojos;

import com.google.gson.Gson;

public class ModelMetricsMultinomialV3 extends ModelMetricsBase {
    /** The R^2 for this scoring run. */
    public double r2;

    /** The hit ratio table for this scoring run. */
    public TwoDimTableV3 hit_ratio_table;

    /** The ConfusionMatrix object for this scoring run. */
    public ConfusionMatrixV3 cm;

    /** The logarithmic loss for this scoring run. */
    public double logloss;

    /** The mean misclassification error per class. */
    public double mean_per_class_error;

    /* INHERITED: The model used for this scoring run. 
    public ModelKeyV3 model = null;
     */

    /* INHERITED: The checksum for the model used for this scoring run. 
    public long model_checksum = 0L;
     */

    /* INHERITED: The frame used for this scoring run. 
    public FrameKeyV3 frame = null;
     */

    /* INHERITED: The checksum for the frame used for this scoring run. 
    public long frame_checksum = 0L;
     */

    /* INHERITED: Optional description for this scoring run (to note out-of-bag, sampled data, etc.) 
    public String description = "";
     */

    /* INHERITED: The category (e.g., Clustering) for the model used for this scoring run. 
    public ModelCategory model_category = null;
     */

    /* INHERITED: The time in mS since the epoch for the start of this scoring run. 
    public long scoring_time = 0L;
     */

    /* INHERITED: Predictions Frame. 
    public FrameV3 predictions = null;
     */

    /* INHERITED: The Mean Squared Error of the prediction for this scoring run. 
    public double MSE = 0.0;
     */

    public ModelMetricsMultinomialV3() {
        r2 = 0.0;
        hit_ratio_table = null;
        cm = null;
        logloss = 0.0;
        mean_per_class_error = 0.0;
        model = null;
        model_checksum = 0L;
        frame = null;
        frame_checksum = 0L;
        description = "";
        model_category = null;
        scoring_time = 0L;
        predictions = null;
        MSE = 0.0;
    }

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}
